Xpanse Issues API
==================

xpanse.api.issues.v1.assignees module
--------------------------------------

.. automodule:: xpanse.api.issues.v1.assignees
    :members:
    :undoc-members:
    :show-inheritance:

xpanse.api.issues.v1.business_units module
-------------------------------------------

.. automodule:: xpanse.api.issues.v1.business_units
    :members:
    :undoc-members:
    :show-inheritance:

xpanse.api.issues.v1.issue_types module
----------------------------------------

.. automodule:: xpanse.api.issues.v1.issue_types
    :members:
    :undoc-members:
    :show-inheritance:

xpanse.api.issues.v1.issues module
-----------------------------------

.. automodule:: xpanse.api.issues.v1.issues
    :members:
    :undoc-members:
    :show-inheritance:

xpanse.api.issues.v1.providers module
--------------------------------------

.. automodule:: xpanse.api.issues.v1.providers
    :members:
    :undoc-members:
    :show-inheritance:

xpanse.api.issues.v1.updates module
------------------------------------

.. automodule:: xpanse.api.issues.v1.updates
    :members:
    :undoc-members:
    :show-inheritance: